@@ -22,7 +22,9 @@ from azdev.utilities import (
     COMMAND_MODULE_PREFIX, EXTENSION_PREFIX,
     make_dirs, get_azdev_config_dir,
     get_path_table, require_virtual_env, get_name_index)
-
+from .pytest_runner import get_test_runner
+from .profile_context import ProfileContext, current_profile
+from .incremental_strategy import CLIAzureDevOpsContext
 
 logger = get_logger(__name__)
 
@@ -30,22 +32,21 @@ logger = get_logger(__name__)
 # pylint: disable=too-many-statements
 def run_tests(tests, xml_path=None, discover=False, in_series=False,
               run_live=False, profile=None, last_failed=False, pytest_args=None,
-              git_source=None, git_target=None, git_repo=None):
+              no_exit_first=False,
+              git_source=None, git_target=None, git_repo=None,
+              cli_ci=False):
 
     require_virtual_env()
 
     DEFAULT_RESULT_FILE = 'test_results.xml'
     DEFAULT_RESULT_PATH = os.path.join(get_azdev_config_dir(), DEFAULT_RESULT_FILE)
 
-    from .pytest_runner import get_test_runner
-
     heading('Run Tests')
 
-    original_profile = _get_profile(profile)
-    if not profile:
-        profile = original_profile
     path_table = get_path_table()
-    test_index = _get_test_index(profile, discover)
+
+    test_index = _get_test_index(profile or current_profile(), discover)
+
     if not tests:
         tests = list(path_table['mod'].keys()) + list(path_table['core'].keys()) + list(path_table['ext'].keys())
     if tests == ['CLI']:
@@ -54,10 +55,13 @@ def run_tests(tests, xml_path=None, discover=False, in_series=False,
         tests = list(path_table['ext'].keys())
 
     # filter out tests whose modules haven't changed
-    tests = _filter_by_git_diff(tests, test_index, git_source, git_target, git_repo)
+    modified_mods = _filter_by_git_diff(tests, test_index, git_source, git_target, git_repo)
+    if modified_mods:
+        display('\nTest on modules: {}\n'.format(', '.join(modified_mods)))
 
-    if tests:
-        display('\nTESTS: {}\n'.format(', '.join(tests)))
+    if cli_ci is True:
+        ctx = CLIAzureDevOpsContext(git_repo, git_source, git_target)
+        modified_mods = ctx.filter(test_index)
 
     # resolve the path at which to dump the XML results
     xml_path = xml_path or DEFAULT_RESULT_PATH
@@ -73,6 +77,7 @@ def run_tests(tests, xml_path=None, discover=False, in_series=False,
         name_comps = name.split('.')
         num_comps = len(name_comps)
         key_error = KeyError()
+
         for i in range(num_comps):
             check_name = '.'.join(name_comps[(-1 - i):])
             try:
@@ -87,7 +92,7 @@ def run_tests(tests, xml_path=None, discover=False, in_series=False,
 
     # lookup test paths from index
     test_paths = []
-    for t in tests:
+    for t in modified_mods:
         try:
             test_path = os.path.normpath(_find_test(test_index, t))
             test_paths.append(test_path)
@@ -95,27 +100,27 @@ def run_tests(tests, xml_path=None, discover=False, in_series=False,
             logger.warning("'%s' not found. If newly added, re-run with --discover", t)
             continue
 
+    exit_code = 0
+
     # Tests have been collected. Now run them.
     if not test_paths:
-        raise CLIError('No tests selected to run.')
+        logger.warning('No tests selected to run.')
+        sys.exit(exit_code)
 
-    runner = get_test_runner(parallel=not in_series, log_path=xml_path, last_failed=last_failed)
-    exit_code = runner(test_paths=test_paths, pytest_args=pytest_args)
-    _summarize_test_results(xml_path)
-
-    # attempt to restore the original profile
-    if profile != original_profile:
-        result = raw_cmd('az cloud update --profile {}'.format(original_profile),
-                         "Restoring profile '{}'.".format(original_profile))
-        if result.exit_code != 0:
-            logger.warning("Failed to restore profile '%s'.", original_profile)
+    exit_code = 0
+    with ProfileContext(profile):
+        runner = get_test_runner(parallel=not in_series,
+                                 log_path=xml_path,
+                                 last_failed=last_failed,
+                                 no_exit_first=no_exit_first)
+        exit_code = runner(test_paths=test_paths, pytest_args=pytest_args)
 
     sys.exit(0 if not exit_code else 1)
 
 
 def _filter_by_git_diff(tests, test_index, git_source, git_target, git_repo):
     from azdev.utilities import diff_branches, extract_module_name
-    from azdev.utilities.git_util import _summarize_changed_mods
+    from azdev.utilities.git_util import summarize_changed_mods
 
     if not any([git_source, git_target, git_repo]):
         return tests
@@ -124,7 +129,7 @@ def _filter_by_git_diff(tests, test_index, git_source, git_target, git_repo):
         raise CLIError('usage error: [--src NAME]  --tgt NAME --repo PATH')
 
     files_changed = diff_branches(git_repo, git_target, git_source)
-    mods_changed = _summarize_changed_mods(files_changed)
+    mods_changed = summarize_changed_mods(files_changed)
 
     repo_path = str(os.path.abspath(git_repo)).lower()
     to_remove = []
@@ -145,30 +150,6 @@ def _filter_by_git_diff(tests, test_index, git_source, git_target, git_repo):
     return tests
 
 
-def _get_profile(profile):
-    import colorama
-    colorama.init(autoreset=True)
-    try:
-        fore_red = colorama.Fore.RED if not IS_WINDOWS else ''
-        fore_reset = colorama.Fore.RESET if not IS_WINDOWS else ''
-        original_profile = raw_cmd('az cloud show --query profile -otsv', show_stderr=False).result
-        if not profile or original_profile == profile:
-            profile = original_profile
-            display('The tests are set to run against current profile {}.'
-                    .format(fore_red + original_profile + fore_reset))
-        elif original_profile != profile:
-            display('The tests are set to run against profile {} but the current az cloud profile is {}.'
-                    .format(fore_red + profile + fore_reset, fore_red + original_profile + fore_reset))
-            result = raw_cmd('az cloud update --profile {}'.format(profile),
-                             'SWITCHING TO PROFILE {}.'.format(fore_red + profile + fore_reset))
-            if result.exit_code != 0:
-                raise CLIError(result.error.output)
-        # returns the original profile so we can switch back if need be
-        return original_profile
-    except CalledProcessError:
-        raise CLIError('Failed to retrieve current az profile')
-
-
 def _discover_module_tests(mod_name, mod_data):
 
     # get the list of test files in each module
@@ -353,32 +334,3 @@ def _get_test_index(profile, discover):
             f.write(json.dumps(test_index))
         display('\ntest index created: {}'.format(test_index_path))
     return test_index
-
-
-def _summarize_test_results(xml_path):
-    import xml.etree.ElementTree as ElementTree
-
-    subheading('Results')
-
-    root = ElementTree.parse(xml_path).getroot()
-    summary = {
-        'time': root.get('time'),
-        'tests': root.get('tests'),
-        'skips': root.get('skips'),
-        'failures': root.get('failures'),
-        'errors': root.get('errors')
-    }
-    display('Time: {time} sec\tTests: {tests}\tSkipped: {skips}\tFailures: {failures}\tErrors: {errors}'.format(
-        **summary))
-
-    failed = []
-    for item in root.findall('testcase'):
-        if item.findall('failure'):
-            file_and_class = '.'.join(item.get('classname').split('.')[-2:])
-            failed.append('{}.{}'.format(file_and_class, item.get('name')))
-
-    if failed:
-        subheading('FAILURES')
-        for name in failed:
-            display(name)
-    display('')
