@@ -4,16 +4,27 @@
 # license information.
 # -----------------------------------------------------------------------------
 
+import os
 
-def get_test_runner(parallel, log_path, last_failed):
+from knack.log import get_logger
+
+from azdev.utilities import call
+
+
+def get_test_runner(parallel, log_path, last_failed, no_exit_first):
     """Create a pytest execution method"""
     def _run(test_paths, pytest_args):
-        from azdev.utilities import call
-        from knack.log import get_logger
 
         logger = get_logger(__name__)
 
-        arguments = ['-p', 'no:warnings', '--no-print-logs', '--junit-xml', log_path]
+        if os.name == 'posix':
+            arguments = ['-x', '-v', '--boxed', '-p no:warnings', '--log-level=WARN', '--junit-xml', log_path]
+        else:
+            arguments = ['-x', '-v', '-p no:warnings', '--log-level=WARN', '--junit-xml', log_path]
+
+        if no_exit_first:
+            arguments.remove('-x')
+
         arguments.extend(test_paths)
         if parallel:
             arguments += ['-n', 'auto']
